generic HighExprsGene function for Splice object
HighExprsGene-Splice-numeric-method.Rdchoose genes with high total expression for phi calculation
Usage
# S4 method for Splice,numeric
HighExprsGene(object, thresh = 100)HighExprsGene-Splice-numeric-method.Rdchoose genes with high total expression for phi calculation
# S4 method for Splice,numeric
HighExprsGene(object, thresh = 100)