metaSpliceSite
metaSpliceSite.RdMerge sites into meta sites based on their co-existence or if they are mutually exclusive
Arguments
- sites_table
The site count table output from sites2matrix()
- eps
The threshold for two sites to be merged
metaSpliceSite.RdMerge sites into meta sites based on their co-existence or if they are mutually exclusive
The site count table output from sites2matrix()
The threshold for two sites to be merged